@@ -1,9 +1,11 @@
-from multiprocessing import get_context
 import threading
+from multiprocessing import get_context
 
 import nonebot
 from nonebot import logger
 
+from .config import plugin_config
+
 _nb_run = nonebot.run
 
 
@@ -11,9 +13,12 @@ class Reloader:
     event: threading.Event = None
 
     @classmethod
-    def reload(cls):
+    def reload(cls, delay: int = 0):
         if cls.event is None:
             raise RuntimeError()
+        if delay > 0:
+            threading.Timer(delay, function=cls.event.set).start()
+            return
         cls.event.set()
 
 
@@ -40,9 +45,11 @@ def run(*args, **kwargs):
             if event.wait(1):
                 logger.info("Receive reboot event")
                 process.terminate()
-                process.join(5)
+                process.join(plugin_config.reboot_grace_time_limit)
                 if process.is_alive():
-                    logger.warning("Cannot shutdown gracefully in 5 second, force kill process.")
+                    logger.warning(
+                        f"Cannot shutdown gracefully in {plugin_config.reboot_grace_time_limit} second, force kill process."
+                    )
                     process.kill()
                 break
             elif process.is_alive():
